@@ -22,6 +22,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcefilesaver.h"
 #include "gtksourcefile.h"
 #include "gtksourcebufferinputstream.h"
@@ -1374,6 +1378,9 @@ gtk_source_file_saver_save_async (GtkSourceFileSaver     *saver,
  * properties will be updated: the location, the encoding, the newline type and
  * the compression type.
  *
+ * Since the 3.20 version, gtk_text_buffer_set_modified() is called with %FALSE
+ * if the file has been saved successfully.
+ *
  * Returns: whether the file was saved successfully.
  * Since: 3.14
  */
@@ -1404,6 +1411,10 @@ gtk_source_file_saver_save_finish (GtkSourceFileSaver  *saver,
 		_gtk_source_file_set_compression_type (saver->priv->file,
 						       saver->priv->compression_type);
 
+		_gtk_source_file_set_externally_modified (saver->priv->file, FALSE);
+		_gtk_source_file_set_deleted (saver->priv->file, FALSE);
+		_gtk_source_file_set_readonly (saver->priv->file, FALSE);
+
 		if (g_file_info_has_attribute (saver->priv->info, G_FILE_ATTRIBUTE_TIME_MODIFIED))
 		{
 			GTimeVal modification_time;
@@ -1412,6 +1423,12 @@ gtk_source_file_saver_save_finish (GtkSourceFileSaver  *saver,
 		}
 	}
 
+	if (ok && saver->priv->source_buffer != NULL)
+	{
+		gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (saver->priv->source_buffer),
+					      FALSE);
+	}
+
 	reset (saver);
 
 	return ok;
